@@ -1,11 +1,10 @@
-# Copyright (C) 2020 Hatching B.V
+# Copyright (C) 2020-2021 Hatching B.V
 # All rights reserved.
 
 from io import StringIO, BytesIO
 from triage.pagination import Paginator
-from urllib.error import HTTPError
-from urllib.request import Request, urlopen
-from urllib import parse
+from requests import Request, Session, exceptions, utils
+
 import binascii
 import json
 import os
@@ -18,35 +17,39 @@ class Client:
         self.token = token
         self.root_url = root_url.rstrip('/')
 
-    def _new_request(self, method, path, data=None):
+    def _new_request(self, method, path, j=None, b=None, headers={}):
         headers = {
             'Authorization': 'Bearer {0}'.format(self.token),
             'User-Agent': 'Triage Python Client/{0} Python/{1}'
                 .format(version, sys.version.split(' ')[0]),
+            **headers
         }
-        return Request(self.root_url + path, headers=headers, data=data,
-            method=method)
+        if j:
+            return Request(method, self.root_url + path, data=json.dumps(j), headers=headers)
+        return Request(method, self.root_url + path, data=b, headers=headers)
 
     def _req_file(self, method, path):
         r = self._new_request(method, path)
-        with urlopen(r) as f:
-            return f.read()
+        with Session() as s:
+            return s.send(r.prepare()).content
 
     def _req_json(self, method, path, data=None):
-        body = None
-        if data is not None:
-            body = StringIO(json.dumps(data))
-        r = self._new_request(method, path, body)
-        if data is not None:
-            r.add_header('Content-Type', 'application/json')
+        if data is None:
+            r = self._new_request(method, path, data)
+        else:
+            r = self._new_request(method, path, data,
+                headers={'Content-Type': 'application/json'})
+
         try:
-            with urlopen(r) as f:
-                return json.load(f)
-        except HTTPError as err:
+            with Session() as s:
+                res = s.send(r.prepare())
+                res.raise_for_status()
+                return res.json()
+        except exceptions.HTTPError as err:
             raise ServerError(err)
 
     def submit_sample_file(self, filename, file, interactive=False,
-                           profiles=[]):
+                           profiles=[], password=None):
         """
         Submit a file for analysis on Triage.
 
@@ -65,6 +68,8 @@ class Client:
                         "profile": "w7_long"
                     }
                 ]
+            password (str):
+                Password for the archive sample
         Returns:
             response (dict):
                 {
@@ -76,20 +81,26 @@ class Client:
                     'submitted': '2020-09-23T07:26:26Z'
                 }
         """
+        d = {
+            'kind': 'file',
+            'interactive': interactive,
+            'profiles': profiles,
+        }
+        if password:
+            d['password'] = password
         body, content_type = encode_multipart_formdata({
-            '_json': json.dumps({
-                'kind': 'file',
-                'interactive': interactive,
-                'profiles': profiles,
-            }),
+            '_json': json.dumps(d),
             'file': (filename, file),
         })
-        r = self._new_request('POST', '/v0/samples', body)
-        r.add_header('Content-Type', content_type)
+        r = self._new_request('POST', '/v0/samples', b=body,
+            headers={"Content-Type": content_type}
+        )
         try:
-            with urlopen(r) as f:
-                return json.load(f)
-        except HTTPError as err:
+            with Session() as s:
+                res = s.send(r.prepare())
+                res.raise_for_status()
+                return res.json()
+        except exceptions.HTTPError as err:
             raise ServerError(err)
 
     def submit_sample_url(self, url, interactive=False, profiles=[]):
@@ -223,6 +234,19 @@ class Client:
         """
         return self._req_json('GET', '/v0/samples/{0}'.format(sample_id))
 
+    def get_sample_file(self, sample_id):
+        """
+        Return the sample file.
+
+        Parameters:
+            sample_id (str): The id of the sample
+
+        Returns:
+            response (file):
+                File object.
+        """
+        return self._req_file("GET", "/v0/samples/{0}/sample".format(sample_id))
+
     def delete_sample(self, sample_id):
         """
         Delete a sample.
@@ -248,8 +272,8 @@ class Client:
             Paginator (object):
                 Loop over this object to get the samples
         """
-        params = parse.urlencode({"query": query})
-        return Paginator(self, '/v0/search?{0}'.format(params), max)
+        params = utils.quote(query)
+        return Paginator(self, '/v0/search?query={0}'.format(params), max)
 
     def static_report(self, sample_id):
         """
@@ -326,18 +350,18 @@ class Client:
                 'GET', '/v0/samples/{0}/{1}/logs/onemon.json'.format(
                     sample_id, task_id)
             )
-            f = urlopen(r)
         elif "linux" in task["platform"]:
             r =  self._new_request(
                 'GET', '/v0/samples/{0}/{1}/logs/stahp.json'.format(
                     sample_id, task_id)
             )
-            f = urlopen(r)
         else:
             raise ValueError("Platform not supported")
 
-        with f:
-            for entry in f.read().split(b"\n"):
+        with Session() as s:
+            res = s.send(r.prepare())
+            res.raise_for_status()
+            for entry in res.content.split(b"\n"):
                 if entry.strip() == b"":
                     break
                 yield json.loads(entry)
@@ -472,13 +496,19 @@ class Client:
             yield of dict events
         """
         events = self._new_request("GET", "/v0/samples/"+sample_id+"/events")
-        for r in urlopen(events):
-            yield json.loads(r)
+        with Session() as s:
+            res = s.send(events.prepare(), stream=True)
+            for line in res.iter_lines():
+                if line:
+                    yield json.loads(line)
+
+def PrivateClient(token):
+    return Client(token, "https://private.tria.ge/api")
 
 class ServerError(Exception):
-    def __init__(self, http_error):
-        b = json.load(http_error)
-        self.status = http_error.status
+    def __init__(self, err):
+        b = err.response.json()
+        self.status = err.response.status_code
         self.kind = b['error']
         self.message = b['message']
 
